<?php

/**
 * ab_coupon package for Concrete5
 * Copyright Copyright 2017-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_coupon
 */

namespace Concrete\Package\AbCoupon\Block\AbCoupon;

use Concrete\Core\Block\BlockController;
use Concrete\Core\Editor\LinkAbstractor;
use Concrete\Core\Package\Package;
use Concrete\Core\File\File;

class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btTable = 'btAbCoupon';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Coupon block");
    }

    public function getBlockTypeName() 
    {
        return t("Coupon");
    }

    public function getBlockUID($b = null) {
        if ($b == null) return null;
        $proxyBlock = $b->getProxyBlock();
        return $proxyBlock? $proxyBlock->getBlockID() : $b->bID;
    }
    
    public function on_start() {
        $this->set('app', $this->app);
        
        $pkg = Package::getByHandle('ab_coupon');
        $img_url = $pkg->getRelativePath() . '/blocks/ab_coupon/images';
        $this->set("img_url", $img_url);
    }
    
    public function registerViewAssets($outputContent = '')
    {
        if($this->popup) {
            $this->requireAsset('core/lightbox');
        }
        $this->requireAsset('javascript', 'jquery');
    }
    
    public function view() 
    {
        $al = \Concrete\Core\Asset\AssetList::getInstance();
        $al->register('javascript', 'jquery.countdown', 'blocks/ab_coupon/js/jquery.countdown.min.js', array('version' => '2.2.0'), 'ab_coupon');
        $this->requireAsset('javascript', 'jquery.countdown');
        
        $this->set('pic', $this->getPictureObject());
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
    }

    public function edit()
    {
        $pic = null;
        if ($this->getPictureID() > 0) {
            $pic = $this->getPictureObject();
        }
        
        $this->set('pic', $pic);
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
    }
    
    public function save($args) 
    {
        $args['pictureID'] = (isset($args['show_picture']) && $args['pictureID'] != 0) ? $args['pictureID'] : 0;
        $args['show_picture'] = (isset($args['show_picture']) && $args['pictureID'] != 0) ? 1 : 0;
        $args['primary_title'] = isset($args['primary_title']) ? $args['primary_title'] : '';
        $args['secondary_title'] = isset($args['secondary_title']) ? $args['secondary_title'] : '';
        $args['show_sale'] = isset($args['show_sale']) ? 1 : 0;
        $args['show_saving'] = isset($args['show_saving']) ? 1 : 0;
        $args['show_until'] = isset($args['show_until']) ? 1 : 0;
        $args['price_before'] = isset($args['price_before']) ? $args['price_before'] : '';
        $args['price_after'] = isset($args['price_after']) ? $args['price_after'] : '';
        $args['currency_symbol'] = isset($args['currency_symbol']) ? $args['currency_symbol'] : '';
        $args['valid_until'] = isset($args['valid_until']) ? $args['valid_until'] : '';
        $args['text_show'] = LinkAbstractor::translateTo($args['text_show']);
        $args['text_hide'] = LinkAbstractor::translateTo($args['text_hide']);
        $args['btn_text'] = isset($args['btn_text']) ? $args['btn_text'] : t('show / hide');
        $args['popup'] = isset($args['popup']) ? 1 : 0;
        parent::save($args);
    }

    public function getPictureID()
    {
        return isset($this->record->pictureID) ? $this->record->pictureID : (isset($this->pictureID) ? $this->pictureID : null);
    }

    public function getPictureObject()
    {
        return File::getByID($this->getPictureID());
    }

    public function getTextShow()
    {
        return LinkAbstractor::translateFromEditMode($this->text_show);
    }

    public function getTextHide()
    {
        return LinkAbstractor::translateFromEditMode($this->text_hide);
    }

}
